@@ -316,7 +316,7 @@ class DatabaseTest(LogCaptureTestCase):
 		ticket.setAttempt(5)
 		self.jail.putFailTicket(ticket)
 		actions._Actions__checkBan()
-		self.assertTrue(self._is_logged("ban ainfo %s, %s, %s, %s" % (True, True, True, True)))
+		self.assertLogged("ban ainfo %s, %s, %s, %s" % (True, True, True, True))
 
 	def testPurge(self):
 		if Fail2BanDb is None: # pragma: no cover
