@@ -312,4 +312,10 @@ else:
 			kernel32.CloseHandle(process)
 			return True
 		else:
-			return False
\ No newline at end of file
+			return False
+
+# Python 2.6 compatibility. in 2.7 assertDictEqual
+def assert_dict_equal(a, b):
+	assert isinstance(a, dict), "Object is not dictionary: %r" % a
+	assert isinstance(b, dict), "Object is not dictionary: %r" % b
+	assert a==b, "Dictionaries differ:\n%r !=\n%r" % (a, b)
